Crate dwldutil
dwldutil
3.1.1
All Items
Crate Items
Modules
Structs
Enums
Crate
dwldutil
Modules

cas
indicator
Structs

DLFile
Struct in which they set the data in a file
DLHashes
Downloader
Struct in which all the files to be downloaded are set up
Enums

DLHash
Type